@@ -24,7 +24,9 @@
 #include <KAboutData>
 
 #include <KLocalizedString>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <Kdelibs4ConfigMigrator>
+#endif
 #include <KCrash>
 
 #include <QApplication>
@@ -34,18 +36,16 @@
 #include <QQmlEngine>
 #include <QCommandLineParser>
 
-static const char description[] =
-        I18N_NOOP("Classical hangman game by KDE");
-
 int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QStringList configFiles;
     configFiles << QStringLiteral("khangmanrc");
     Kdelibs4ConfigMigrator migrator(QStringLiteral("khangman"));
     migrator.setConfigFiles(configFiles);
     migrator.migrate();
+#endif
 
     KLocalizedString::setApplicationDomain("khangman");
     QApplication::setApplicationName(QStringLiteral("khangman"));
@@ -56,10 +56,10 @@ int main(int argc, char **argv)
 
     app.connect(&app, &QGuiApplication::lastWindowClosed, &app, &QCoreApplication::quit);
 
-    KAboutData aboutData(I18N_NOOP("khangman"),
+    KAboutData aboutData(QStringLiteral("khangman"),
                          i18n("KHangMan"),
                          QStringLiteral(KHANGMAN_VERSION_STRING),
-                         i18n(description),
+                         i18n("Classical hangman game by KDE"),
                          KAboutLicense::GPL,
                          i18n("(c) 2001-2011, Anne-Marie Mahfouf"));
     aboutData.addAuthor(i18n("Primoz Anzur"), i18n("Previous maintainer"),
@@ -142,13 +142,13 @@ int main(int argc, char **argv)
     QFont f(QStringLiteral("Domestic Manners"), 12, QFont::Normal, true);
     if (!QFontInfo(f).exactMatch())
     {
-        QFontDatabase::addApplicationFont(QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("fonts/Domestic_Manners.ttf")));
+        QFontDatabase::addApplicationFont(QStandardPaths::locate(QStandardPaths::AppLocalDataLocation, QStringLiteral("fonts/Domestic_Manners.ttf")));
     }
 
     QFont fd(QStringLiteral("Dustismo Roman"), 12, QFont::Normal, true);
     if (!QFontInfo(fd).exactMatch())
     {
-        QFontDatabase::addApplicationFont(QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("fonts/Dustismo_Roman.ttf")));
+        QFontDatabase::addApplicationFont(QStandardPaths::locate(QStandardPaths::AppLocalDataLocation, QStringLiteral("fonts/Dustismo_Roman.ttf")));
     }
 
     KHangMan hangman;
